import pytest

from datetime import date, datetime
from utilspy_g4 import to_date


def test_1():
    assert to_date(None) is None

    d = date(2010, 1, 2)
    assert to_date(d) == d


def test_2():
    dt = datetime(2010, 1, 2)
    d = to_date(dt)

    assert d.day == 2
    assert d.month == 1
    assert d.year == 2010


def test_3():
    str_date = '2006.05.30'
    d = to_date(str_date)

    assert d.day == 30
    assert d.month == 5
    assert d.year == 2006

    str_date = '2016-12-23'
    d = to_date(str_date)

    assert d.day == 23
    assert d.month == 12
    assert d.year == 2016

    str_date = '1934/02/03'
    d = to_date(str_date)

    assert d.day == 3
    assert d.month == 2
    assert d.year == 1934

    str_date = '28.10.1990'
    d = to_date(str_date)

    assert d.day == 28
    assert d.month == 10
    assert d.year == 1990

    str_date = '08-01-1888'
    d = to_date(str_date)

    assert d.day == 8
    assert d.month == 1
    assert d.year == 1888

    str_date = '21/12/2120'
    d = to_date(str_date)

    assert d.day == 21
    assert d.month == 12
    assert d.year == 2120


def test_4():
    with pytest.raises(TypeError):
        to_date(123)

    with pytest.raises(TypeError):
        to_date('no date')

    str_date = '32/30/2120'
    with pytest.raises(ValueError):
        to_date(str_date)

    with pytest.raises(TypeError):
        to_date('')



import pytest

from utilspy_g4 import get_files_count


def test_1():
    assert get_files_count('tests/test_getFilesCount/foo_?.txt') == 3

    assert get_files_count('tests/test_getFilesCount/bar_*.txt') == 2

    assert get_files_count('tests/test_getFilesCount/foo.txt') == 1

    assert get_files_count('tests/test_getFilesCount/test_?.txt') == 0

    assert get_files_count('tests/test_getFilesCount_test/foo_?.txt') == 0



import pytest
import os
from utilspy_g4 import templated_remove_files


def test_1():
    open('tests/tmp/test_1.txt', 'a').close()
    open('tests/tmp/test_2.txt', 'a').close()
    open('tests/tmp/test_1.png', 'a').close()
    open('tests/tmp/test_2.png', 'a').close()

    templated_remove_files('tests/tmp/test_1.txt')

    assert os.path.exists('tests/tmp/test_1.txt') is False
    assert os.path.exists('tests/tmp/test_2.txt')
    assert os.path.exists('tests/tmp/test_1.png')
    assert os.path.exists('tests/tmp/test_2.png')

    templated_remove_files('tests/tmp/test_*.png')

    assert os.path.exists('tests/tmp/test_2.txt')
    assert os.path.exists('tests/tmp/test_1.png') is False
    assert os.path.exists('tests/tmp/test_2.png') is False

    templated_remove_files('tests/tmp/test_*')

    assert os.path.exists('tests/tmp/test_2.txt') is False



import os
import glob
from datetime import date, datetime


def add_ext(path: str, ext: str) -> str:
    """
    Add ext to path

    :param path: Path to file
    :param ext: Added ext
    :rtype: str
    :return: Path with added ext
    """

    path_ext = os.path.splitext(path)
    return path_ext[0] + '.' + ext + path_ext[1]


def del_ext(path: str, ext_count: int = 1) -> str:
    """
    Del ext from path

    :param path: Path to file
    :param ext_count: Count of deleted ext
    :rtype: str
    :return: Path without ext
    """

    path_no_ext = path
    for _ in range(ext_count):
        path_no_ext = os.path.splitext(path_no_ext)[0]

    return path_no_ext


def templated_remove_files(template: str) -> None:
    """
    Remove files by template

    :param template: Template
    :return: None
    """

    remove_files = glob.iglob(template)

    for file in remove_files:
        os.remove(file)


def get_ext(path: str, ext_count: int = 1) -> str:
    """
    Return file extension from path

    :param path: Path to file
    :param ext_count: Count of returned extension
    :rtype: str
    :return: Extension
    """

    path_no_ext = path
    last_ext = ''
    for _ in range(ext_count):
        split_path = os.path.splitext(path_no_ext)
        path_no_ext = split_path[0]
        last_ext = split_path[1]

    if last_ext != '':
        # Del .
        last_ext = last_ext[1:]

    return last_ext


def get_files_count(files_template: str) -> int:
    """
    Get files count from filesTemplate
    :param files_template:
    :return: Files count from files_template
    """

    files = glob.iglob(files_template)

    i = 0
    for _ in files:
        i += 1

    return i


def int_to_2str(number: int) -> str:
    """
    Convert integer to 2 chars string with 0
    :param number: 1 or 2 digit integer number
    :return: 2 chars number with 0
    """

    if number < 10:
        return '0' + str(number)

    return str(number)


def to_date(date_) -> date or None:
    """
    Convert date in various formats to date format

    :param date_: date in various formats
    :return: date format
    """
    if isinstance(date_, date) or date_ is None:
        return date_
    elif isinstance(date_, str):
        template = date_template(date_)
        if template is None:
            raise TypeError()
        d = datetime.strptime(date_, template)
        return date(d.year, d.month, d.day)
    elif isinstance(date_, datetime):
        return date(date_.year, date_.month, date_.day)
    else:
        raise TypeError()


def date_template(date_: str) -> str or None:
    """
    Formats: '2006.05.30', '2006-05-30', '2006/05/30', '30.05.2006', '30-05-2006', '30/05/2006'

    :param date_: String date
    :return: date template
    """

    try:
        if date_[4] == '.' and date_[7] == '.':
            return '%Y.%m.%d'

        if date_[4] == '-' and date_[7] == '-':
            return '%Y-%m-%d'

        if date_[4] == '/' and date_[7] == '/':
            return '%Y/%m/%d'

        if date_[2] == '.' and date_[5] == '.':
            return '%d.%m.%Y'

        if date_[2] == '-' and date_[5] == '-':
            return '%d-%m-%Y'

        if date_[2] == '/' and date_[5] == '/':
            return '%d/%m/%Y'
    except IndexError:
        return None

    return None



import pytest
from utilspy_g4 import int_to_2str


def test_1():
    assert int_to_2str(2) == '02'

    assert int_to_2str(0) == '00'

    assert int_to_2str(34) == '34'

    assert int_to_2str(10) == '10'



import pytest
from utilspy_g4 import del_ext


def test_1():
    path = 'test.png'
    new_path = del_ext(path)
    assert new_path == 'test'


def test_2():
    path = '/test/test.jpeg'
    new_path = del_ext(path)
    assert new_path == '/test/test'


def test_3():
    path = 'c:\\test\\test.p'
    new_path = del_ext(path)
    assert new_path == 'c:\\test\\test'


def test_4():
    path = 'd:\\test\\test.png.jpeg'
    new_path = del_ext(path)
    assert new_path == 'd:\\test\\test.png'


def test_5():
    path = 'd:\\test\\test.png.jpeg'
    new_path = del_ext(path, 2)
    assert new_path == 'd:\\test\\test'


def test_6():
    path = '/test/test.png.jpeg'
    new_path = del_ext(path, 2)
    assert new_path == '/test/test'


def test_7():
    path = 'test.jpeg.png'
    new_path = del_ext(path, 2)
    assert new_path == 'test'



import pytest

from utilspy_g4 import date_template


def test_1():
    assert date_template('2006.05.30') == '%Y.%m.%d'

    assert date_template('2016-12-23') == '%Y-%m-%d'

    assert date_template('1934/02/03') == '%Y/%m/%d'

    assert date_template('28.10.1990') == '%d.%m.%Y'

    assert date_template('08-01-1888') == '%d-%m-%Y'

    assert date_template('21/12/2120') == '%d/%m/%Y'


def test_2():
    assert date_template('1/2/22') is None

    assert date_template('no date') is None

    assert date_template('') is None



import pytest
from utilspy_g4 import get_ext


def test_1():
    path = 'test.png'
    ext = get_ext(path)
    assert ext == 'png'


def test_2():
    path = 'test.png'
    ext = get_ext(path, 0)
    assert ext == ''


def test_3():
    path = '/test/test/test.png.jpeg'
    ext = get_ext(path)
    assert ext == 'jpeg'


def test_4():
    path = 'd:\\test\\test.png.jpeg'
    ext = get_ext(path, 2)
    assert ext == 'png'


def test_5():
    path = '/foo/bar/test.txt.png.jpeg'
    ext = get_ext(path, 3)
    assert ext == 'txt'



import pytest
from utilspy_g4 import add_ext


def test_1():
    path = 'c:\\test\\test.png'
    ext = 'ext'
    new_path = add_ext(path, ext)
    assert new_path == 'c:\\test\\test.ext.png'


def test_2():
    path = '/test/test.png'
    ext = 'ext'
    new_path = add_ext(path, ext)
    assert new_path == '/test/test.ext.png'


def test_3():
    path = 'test.png'
    ext = 'ext'
    new_path = add_ext(path, ext)
    assert new_path == 'test.ext.png'


def test_4():
    path = 'c:\\test\\test'
    ext = 'ext'
    new_path = add_ext(path, ext)
    assert new_path == 'c:\\test\\test.ext'


def test_5():
    path = 'c:\\test\\test.2.png'
    ext = 'ext'
    new_path = add_ext(path, ext)
    assert new_path == 'c:\\test\\test.2.ext.png'
